@@ -61,8 +61,8 @@ class mysql(object):
 	def __init__(self, key=127,**args):
 		import pymysql
 		self.pymysql=pymysql
-		_CONNECT_CONFIG={127:{'host':'127.0.0.1','user':'root','password':'','db':'localhost','charset':'utf8','cursorclass':pymysql.cursors.DictCursor}}
-		connect_config = _CONNECT_CONFIG[key]
+		connect_config={'host':'127.0.0.1','user':'root','password':'','db':'localhost','charset':'utf8','cursorclass':pymysql.cursors.DictCursor}
+		if '.' in key:connect_config['host']=key
 		if 'table' in args:
 			self.table=args['table']
 			del args['table']
